<?php
/*
Author : Witoon Pomipon
Email : codebee2014@gmail.com
Website : codebee.co.th
Company : codebee company limited
*/

class Utils{
	public function time_elapsed($datetime, $full = false) {
		date_default_timezone_set("Asia/Bangkok");
		$now = new DateTime;
		$ago = new DateTime($datetime);
		$diff = $now->diff($ago);
		$diff->w = floor($diff->d / 7);
		$diff->d -= $diff->w * 7;
	
		$string = array(
			'y' => 'year',
			'm' => 'month',
			'w' => 'week',
			'd' => 'day',
			'h' => 'hour',
			'i' => 'minute',
			's' => 'second'
		);
		foreach ($string as $k => &$v) {
			if ($diff->$k) {
				$v = $diff->$k . ' ' . $v . ($diff->$k > 1 ? 's' : '');
			} else {
				unset($string[$k]);
			}
		}
		
		if (!$full) $string = array_slice($string, 0, 1);
		$string = str_replace('months','เดือน',$string);
		$string = str_replace('month','เดือน',$string);
		$string = str_replace('weeks','สัปดาห์',$string);
		$string = str_replace('week','สัปดาห์',$string);
		$string = str_replace('days','วัน',$string);
		$string = str_replace('day','วัน',$string);
		$string = str_replace('hours','ชั่วโมง',$string);
		$string = str_replace('hour','ชั่วโมง',$string);
		$string = str_replace('minutes','นาที',$string);
		$string = str_replace('minute','นาที',$string);
		$string = str_replace('seconds','วินาที',$string);
		$string = str_replace('second','วินาที',$string);
		
		return $string ? $string = implode(' ', $string) . ' ที่แล้ว' : 'เมื่อสักครู่';
	}
	public function number_shorten($number, $precision = 3, $divisors = null) {
		if (!isset($divisors)) {
			$divisors = array(
				pow(1000, 0) => '', 
				pow(1000, 1) => 'K', 
				pow(1000, 2) => 'M', 
				pow(1000, 3) => 'B', 
				pow(1000, 4) => 'T', 
				pow(1000, 5) => 'Qa', 
				pow(1000, 6) => 'Qi', 
			);    
		}
		foreach ($divisors as $divisor => $shorthand) {
			if (abs($number) < ($divisor * 1000)) {
				break;
			}
		}
		return number_format($number / $divisor, $precision) . $shorthand;
	}
	public function random_code($length = 8) {
		  $chars = 'abcdefghijklmnopqrstuvwxyz1234567890';
		  $ret = '';
		  for($i = 0; $i < $length; ++$i) {
			$random = str_shuffle($chars);
			$ret .= $random[0];
		  }
		  return $ret;
	}
	public function get_thai_date($timestamp)
	{
		 $mons = array(1 => "มกราคม", 2 => "กุมภาพันธ์", 3 => "มีนาคม", 4 => "เมษายน", 5 => "พฤษภาคม", 6 => "มิถุนายน", 7 => "กรกฎาคม", 8 => "สิงหาคม", 9 => "กันยายน", 10 => "ตุลาคม", 11 => "พฤศจิกายน", 12 => "ธันวาคม");
		
		 $month_arr = explode("-",$timestamp);
		 $month_num = intval($month_arr[1]);
		
		 $month_name = $mons[$month_num];
		 $year_name = $month_arr[0];
		 $date_name = $month_arr[2];
		 $date_arr = explode(" ",$date_name);
		 $date_name = $date_arr[0];
		 return $date_name." ".$month_name." ".$year_name;
	}
	public function day_diff($timestamp){
		$timestamp_arr = explode("-",$timestamp);
		$your_year = $timestamp_arr[0];
		$your_month = $timestamp_arr[1];
		$your_day = $timestamp_arr[2];
		$current_date = date("U");
		
		$date = date($your_year."-".$your_month."-".$your_day);
		$selected_date_stamp = strtotime($date);
		
		$selected_date = date("U",$selected_date_stamp);
		$difference = round (($current_date - $selected_date)/(3600*24));
		return ($difference);
	}
	
	public function get_client_ip() {
		$ipaddress = '';
		if (isset($_SERVER['HTTP_CLIENT_IP']))
			$ipaddress = $_SERVER['HTTP_CLIENT_IP'];
		else if(isset($_SERVER['HTTP_X_FORWARDED_FOR']))
			$ipaddress = $_SERVER['HTTP_X_FORWARDED_FOR'];
		else if(isset($_SERVER['HTTP_X_FORWARDED']))
			$ipaddress = $_SERVER['HTTP_X_FORWARDED'];
		else if(isset($_SERVER['HTTP_FORWARDED_FOR']))
			$ipaddress = $_SERVER['HTTP_FORWARDED_FOR'];
		else if(isset($_SERVER['HTTP_FORWARDED']))
			$ipaddress = $_SERVER['HTTP_FORWARDED'];
		else if(isset($_SERVER['REMOTE_ADDR']))
			$ipaddress = $_SERVER['REMOTE_ADDR'];
		else
			$ipaddress = 'UNKNOWN';
		return $ipaddress;
	}
}
?>